use serde::{Deserialize, Serialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
#[repr(u8)]
pub enum PulseInterpolation {
    Constant = 1,
    JumpChange = 2,
    Linear = 3,
    Bilinear = 4,
    Cubic = 5,
    Bezier = 6,
}

impl PulseInterpolation {
    fn as_u8(&self) -> u8 {
        self.clone() as u8
    }

    fn as_str(&self) -> String {
        self.as_u8().to_string()
    }
}

impl TryFrom<&str> for PulseInterpolation {
    type Error = String;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        match value.parse::<u8>() {
            Ok(1) => Ok(PulseInterpolation::Constant),
            Ok(2) => Ok(PulseInterpolation::JumpChange),
            Ok(3) => Ok(PulseInterpolation::Linear),
            Ok(4) => Ok(PulseInterpolation::Bilinear),
            Ok(5) => Ok(PulseInterpolation::Cubic),
            Ok(6) => Ok(PulseInterpolation::Bezier),
            _ => Err(format!("Invalid Pulse Interpolation value: {}", value)),
        }
    }
}

#[derive(Debug, Clone, Serialize, Deserialize)]
#[repr(u8)]
pub enum FrequencyChange {
    Constant = 1,
    Linear = 2,
    EaseIn = 3,
    EaseOut = 4,
    Randomize = 5,
}

impl FrequencyChange {
    fn as_u8(&self) -> u8 {
        self.clone() as u8
    }

    fn as_str(&self) -> String {
        self.as_u8().to_string()
    }
}

impl TryFrom<&str> for FrequencyChange {
    type Error = String;

    fn try_from(value: &str) -> Result<Self, Self::Error> {
        match value.parse::<u8>() {
            Ok(1) => Ok(FrequencyChange::Constant),
            Ok(2) => Ok(FrequencyChange::Linear),
            Ok(3) => Ok(FrequencyChange::EaseIn),
            Ok(4) => Ok(FrequencyChange::EaseOut),
            Ok(5) => Ok(FrequencyChange::Randomize),
            _ => Err(format!("Invalid Frequency Change value: {}", value)),
        }
    }
}
