import { Icon } from '@iconify/react/dist/iconify.js';
import { FC, useMemo } from 'react';
import { SharedIconProps } from './shared-props';

type IconBluetoothProps = SharedIconProps & {
  ready?: boolean | null;
  searching?: boolean | null;
  connected?: boolean | null;
};

const IconBluetooth: FC<IconBluetoothProps> = ({
  height = 24,
  aspect = 1,
  stroke = 0.5,
  ready = false,
  searching = false,
  connected = false,
}) => {
  const width = useMemo(() => height * aspect, [height, aspect]);
  const bleIcon = useMemo(() => {
    if (ready && !searching && !connected) {
      return 'material-symbols-light:bluetooth';
    } else if (ready && searching) {
      return 'material-symbols-light:bluetooth-searching';
    } else if (ready && !searching && connected) {
      return 'material-symbols-light:bluetooth-connected';
    } else {
      return 'material-symbols-light:bluetooth-disabled';
    }
  }, [ready, searching, connected]);

  return <Icon icon={bleIcon} width={width} height={height} stroke={stroke} />;
};

export default IconBluetooth;
